@@ -107,7 +107,6 @@ sub poster_config { # posting to CoreSmokeDB
             'LWP::UserAgent' => [
                 ua_timeout(),
             ],
-            'HTTP::Lite' => [],
             'HTTP::Tiny' => [],
             'curl' => [
                 curlbin(),
@@ -422,7 +421,7 @@ sub gitorigin {
     return $opt->new(
         name => 'gitorigin',
         option => '=s',
-        default => 'git://github.com/Perl/perl5.git',
+        default => 'https://github.com/Perl/perl5.git',
         helptext => "The remote location of the git repository.",
     );
 }
@@ -655,7 +654,7 @@ sub poster {
     return $opt->new(
         name     => 'poster',
         option   => '=s',
-        allow    => [qw/LWP::UserAgent HTTP::Lite HTTP::Tiny curl/],
+        allow    => [qw/LWP::UserAgent HTTP::Tiny curl/],
         default  => 'LWP::UserAgent',
         helptext => "The type of HTTP post system to use.",
     );
